@@ -86,7 +86,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -154,5 +154,12 @@
 #define KWIDGETSADDONS_DEPRECATED_VERSION_5(minor, text)      KWIDGETSADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text)
+#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KWIDGETSADDONS_EXPORT_H */
